Optional clients and shipments that are not part of any route (prize-collecting problems).
Arguments
- x
A
vrp_solution()orvrp_solve()result.- ...
Unused.
Optional clients and shipments that are not part of any route (prize-collecting problems).
A vrp_solution() or vrp_solve() result.
Unused.