In prize-collecting problems, clients with required = FALSE may be left out
if the prize does not offset the routing cost.
Arguments
- x
A
vrp_solve()result.- ...
Unused.
In prize-collecting problems, clients with required = FALSE may be left out
if the prize does not offset the routing cost.
A vrp_solve() result.
Unused.