Builds PyVRP's C++ ProblemData structure from a vrp_model(). Locations
follow PyVRP's convention: depots first (low indices), then clients.
Arguments
- model
A
vrp_model()with at least one depot and one vehicle type.- distance, duration
Matrices (
numeric,n x n, locations in depots-then-clients order) of distance and duration. IfNULL, they are computed as the rounded Euclidean distance between coordinates;durationdefaults todistance.